devicesinlan - Turulomio

# NAME

devicesinlan: Scans all devices in your LAN. Then you can set an alias to your known devices in order to detect future strange devices in your net.

# SYNOPSIS

devicesinlan [-h] [--version] [--method {PingArp,ScapyArping,Scapy}] [--interface INTERFACE | --add | --remove | --list | --load LOAD | --save SAVE | --reset] [--debug DEBUG]

# DESCRIPTION

If you launch DevicesInLan without parameters a console wizard is launched.

Morever you can use one of this parameters.

--interface

Scans the net of the interface parameter and prints a list of the detected devices.

If a device is not known, it will be showed in red. Devices in green are trusted devices.

--add

Allows to add a known device from console.

--remove

Allows to remove a known device from console.

--list

Shows all known devices in database from console.

--load

Loads a list of known devices in xml format.

--save

Saves the known devices list to a xml file.

--debug

Gives debugging information when running DevicesInLAN. It's deactivated by default

The parameter can take this options: CRITICAL, ERROR, WARNING, INFO, DEBUG.

--reset

Removes all known devices.

# SCAN METHODS

DevicesInLan can use several methods to scan for devices. You just need to add the --method in console mode.

PingArp

It tries to make a socket connection with any device in the lan. Then it searches with 'arp' command the mac information

PingArp method is used in windows and linux versions by default.

Scapy

Uses Scapy to create an ARP request and capture its answer for each ip in the subnet to get macs information.

This method can be used in windows and linux versions, but it needs to be executed with administrator role.

Morever, you need to install 'npcap' in order to execute it in Windows.

ScapyArping

Uses Scapy arping function to create ARP request and capture its answer for each ip in the subnet to get macs information.

This method can be used in windows and linux versions, but it needs to be executed with administrator role.

Morever, you need to install 'npcap' in order to execute it in Windows.

# EXAMPLES

devicesinlan

Default command. It uses PingArp method.

devicesinlan --method ScapyArping

It uses ScapyArping method.

Created with libmangenerator at 2025-12-28